/* Copyright 2004 Acegi Technology Pty Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.acegisecurity.adapters;

import net.sf.acegisecurity.Authentication;
import net.sf.acegisecurity.ui.AbstractIntegrationFilter;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.servlet.ServletRequest;
import javax.servlet.http.HttpServletRequest;


/**
 * Populates a {@link net.sf.acegisecurity.context.SecureContext} from the
 * container's <code>HttpServletRequest.getUserPrincipal()</code>.
 * 
 * <p>
 * See {@link AbstractIntegrationFilter} for further information.
 * </p>
 *
 * @author Ben Alex
 * @version $Id$
 */
public class HttpRequestIntegrationFilter extends AbstractIntegrationFilter {
    //~ Static fields/initializers =============================================

    private static final Log logger = LogFactory.getLog(HttpRequestIntegrationFilter.class);

    //~ Methods ================================================================

    /**
     * Not supported for this type of well-known location.
     *
     * @param request DOCUMENT ME!
     * @param authentication DOCUMENT ME!
     */
    public void commitToContainer(ServletRequest request,
        Authentication authentication) {}

    public Object extractFromContainer(ServletRequest request) {
        if (request instanceof HttpServletRequest) {
            return ((HttpServletRequest) request).getUserPrincipal();
        } else {
            return null;
        }
    }
}
